@@ -416,143 +416,6 @@ BackpackStatHook = simple_hook(
 )
 
 
-class PacketHook(MemoryHook):
-    def __init__(self, memory_handler):
-        super().__init__(memory_handler)
-        self.packet_buffer_addr = None
-        self.socket_discriptor = None
-        self.packet_buffer_len = None
-
-        self.old_protection = None
-
-    def set_packet_buffer_addr(self):
-        self.packet_buffer_addr = self.memory_handler.process.allocate(4)
-
-    def set_socket_discriptor(self):
-        self.socket_discriptor = self.memory_handler.process.allocate(4)
-
-    def set_packet_buffer_len(self):
-        self.packet_buffer_len = self.memory_handler.process.allocate(4)
-
-    def free_packet_buffer_addr(self):
-        self.memory_handler.process.free(self.packet_buffer_addr)
-
-    def free_socket_discriptor(self):
-        self.memory_handler.process.free(self.socket_discriptor)
-
-    def free_packet_buffer_len(self):
-        self.memory_handler.process.free(self.packet_buffer_len)
-
-    def get_jump_address(self, pattern: re.Pattern, *, module=None) -> int:
-        """
-        gets the address to write jump at
-        """
-        # exact location of wsock.recv + 2 which should never change
-        jump_address = module.lpBaseOfDll + 0x1E32
-        # I could read jump_address and compare to pattern but it's really unneeded
-        return jump_address
-
-    def get_pattern(self) -> Tuple[re.Pattern, Optional[MODULEINFO]]:
-        module = pymem.process.module_from_name(
-            self.memory_handler.process.process_handle, "WSOCK32.dll"
-        )
-        return (
-            re.compile(rb"\x8B\xFF\x55\x8B\xEC\x83\xEC.\x8B\x45.\x89\x45"),
-            module,
-        )
-
-    def get_jump_bytecode(self) -> bytes:
-        # distance = end - start
-        distance = self.hook_address - self.jump_address
-        relitive_jump = distance - 5  # size of this line
-        packed_relitive_jump = struct.pack("<i", relitive_jump)
-        return b"\xE9" + packed_relitive_jump + b"\x90"
-
-    def get_hook_bytecode(self) -> bytes:
-        self.set_packet_buffer_addr()
-        packed_buffer_addr = struct.pack("<i", self.packet_buffer_addr)
-
-        self.set_socket_discriptor()
-        packed_socket_discriptor = struct.pack("<i", self.socket_discriptor)
-
-        self.set_packet_buffer_len()
-        packed_buffer_len = struct.pack("<i", self.packet_buffer_len)
-
-        ecx_tmp = self.memory_handler.process.allocate(4)
-        packed_ecx_tmp = struct.pack("<i", ecx_tmp)
-
-        # stack is stored here so we can restore it
-        stack_buffer_tmp = self.memory_handler.process.allocate(16)
-        packed_stack_buffer_tmp = struct.pack("<i", stack_buffer_tmp)
-        packed_stack_buffer_tmp_4 = struct.pack("<i", stack_buffer_tmp + 0x4)
-        packed_stack_buffer_tmp_8 = struct.pack("<i", stack_buffer_tmp + 0x8)
-        packed_stack_buffer_tmp_12 = struct.pack("<i", stack_buffer_tmp + 0x12)
-
-        # this is the function I'm hooking
-        # int recv(
-        #  SOCKET s,
-        #  char * buf,
-        #  int len,
-        #  int flags);
-
-        bytecode = (
-            b"\x89\x0D" + packed_ecx_tmp +  # mov [ecx_tmp],ecx
-            # reading args backwards (__stdcall)
-            # int flags
-            b"\x59"  # pop ecx
-            b"\x89\x0D" + packed_stack_buffer_tmp +  # mov [stack_buffer],ecx
-            # int len
-            b"\x59"  # pop ecx
-            b"\x89\x0D"
-            + packed_stack_buffer_tmp_4  # mov [stack_buffer+4],ecx
-            + b"\x89\x0D"
-            + packed_buffer_len  # mov [buffer_len],ecx
-            +
-            # char * buf
-            b"\x59"  # pop ecx
-            b"\x89\x0D" + packed_stack_buffer_tmp_8 +  # mov [stack_buffer+8],ecx
-            # move the buf pointer to our address
-            b"\x89\x0D" + packed_buffer_addr +  # mov [buffer_addr],ecx
-            # SOCKET s
-            b"\x59"  # pop ecx
-            b"\x89\x0D" + packed_stack_buffer_tmp_12 +  # mov [stack_buffer+12],ecx
-            # move the socket descriptor to our addr
-            b"\x89\x0D"
-            + packed_socket_discriptor  # mov [socket_descriptor],ecx { (32768) }
-            +
-            # fix the stack for the rest of the recv function
-            b"\x8B\x0D"
-            + packed_stack_buffer_tmp_12  # mov ecx,[stack_buffer+12]
-            + b"\x51"  # push ecx
-            b"\x8B\x0D"
-            + packed_stack_buffer_tmp_8  # mov ecx,[stack_buffer+8]
-            + b"\x51"  # push ecx
-            b"\x8B\x0D" + packed_stack_buffer_tmp_4 + b"\x51"  # see above
-            b"\x8B\x0D" + packed_stack_buffer_tmp + b"\x51"
-            b"\x8B\x0D" + packed_ecx_tmp +  # move ecx,[ecx_tmp]
-            # original code
-            b"\x55"  # push ebp
-            b"\x8B\xEC"  # mov ebp,esp
-            b"\x83\xEC\x10"  # sub esp,10
-        )
-
-        # WSOCK.recv+8 (jump_address is +2)
-        return_addr = self.jump_address + 6
-
-        relitive_return_jump = return_addr - (self.hook_address + len(bytecode)) - 5
-        packed_relitive_return_jump = struct.pack("<i", relitive_return_jump)
-
-        bytecode += b"\xE9" + packed_relitive_return_jump
-
-        return bytecode
-
-    def unhook(self):
-        super().unhook()
-        self.free_packet_buffer_addr()
-        self.free_packet_buffer_len()
-        self.free_socket_discriptor()
-
-
 class MoveLockHook(MemoryHook):
     def __init__(self, memory_handler):
         super().__init__(memory_handler)
@@ -678,3 +541,87 @@ class PotionsAltHook(MemoryHook):
     def unhook(self):
         super().unhook()
         self.free_potions_alt_addr()
+
+
+class MouselessCursorMoveHook(MemoryHook):
+    def __init__(self, memory_handler):
+        super().__init__(memory_handler)
+        self.x_addr = None
+        self.y_addr = None
+
+    def set_mouse_pos_addrs(self):
+        self.x_addr = self.memory_handler.process.allocate(4)
+        self.y_addr = self.memory_handler.process.allocate(4)
+
+    def free_mouse_pos_addrs(self):
+        self.memory_handler.process.free(self.x_addr)
+        self.memory_handler.process.free(self.y_addr)
+
+    def get_jump_bytecode(self) -> bytes:
+        # distance = end - start
+        distance = self.hook_address - self.jump_address
+        relitive_jump = distance - 5  # size of this line
+        packed_relitive_jump = struct.pack("<i", relitive_jump)
+        return b"\xE9" + packed_relitive_jump
+
+    def get_hook_bytecode(self) -> bytes:
+        self.set_mouse_pos_addrs()
+        packed_xpos_addr = struct.pack("<i", self.x_addr)
+        packed_ypos_addr = struct.pack("<i", self.y_addr)
+
+        bytecode = (
+            b"\x50"  # push eax
+            b"\x8b\x44\x24\x08"  # mov eax, dword ptr [esp+0x8]
+            b"\x51"  # push ecx
+            b"\x8b\x0d"
+            + packed_xpos_addr
+            + b"\x89\x08"  # mov ecx, dword ptr x_addr  # mov dword ptr [eax], ecx
+            b"\x8b\x0d"
+            + packed_ypos_addr
+            + b"\x89\x48\x04"  # mov ecx, dword ptr y_addr  # mov dword ptr [eax+0x4], ecx
+            b"\x59"  # pop ecx
+            b"\x58"  # pop eax
+            b"\xc2\x04\x00"  # ret 0x4
+        )
+
+        return bytecode
+
+    def get_pattern(self) -> Tuple[re.Pattern, Optional[MODULEINFO]]:
+        module = pymem.process.module_from_name(
+            self.memory_handler.process.process_handle, "user32.dll"
+        )
+        return (
+            re.compile(rb"((\x8B\xFF\x55\x8B\xEC)|(\xE9....))\x6A\x7F\x6A\x01"),
+            module,
+        )
+
+    def hook(self) -> Any:
+        """
+        Writes jump_bytecode to jump address and hook bytecode to hook address
+        """
+        pattern, module = self.get_pattern()
+
+        self.jump_address = self.get_jump_address(pattern, module=module)
+        self.hook_address = self.get_hook_address(200)
+
+        self.jump_bytecode = self.get_jump_bytecode()
+        self.hook_bytecode = self.get_hook_bytecode()
+
+        self.jump_original_bytecode = self.memory_handler.process.read_bytes(
+            self.jump_address, len(self.jump_bytecode)
+        )
+
+        self.memory_handler.process.write_bytes(
+            self.hook_address, self.hook_bytecode, len(self.hook_bytecode),
+        )
+        self.memory_handler.process.write_bytes(
+            self.jump_address, self.jump_bytecode, len(self.jump_bytecode),
+        )
+
+        # TODO: replace static address
+        self.memory_handler.process.write_char(0x012E973C + 6, chr(1))
+
+    def unhook(self):
+        super().unhook()
+        self.free_mouse_pos_addrs()
+        self.memory_handler.process.write_char(0x012E973C + 6, chr(0))
